@@ -55,13 +55,25 @@ impl<'a> ConvertParser<'a> {
             InputType::Dir => {
                 let dir = self.parse_dir_input(self.matches);
                 let files = self.get_files(dir, &self.input_fmt);
-                self.print_input_multi(&Some(dir), task_desc, files.len(), &self.input_fmt);
+                self.print_input_multi(
+                    &Some(dir),
+                    task_desc,
+                    files.len(),
+                    &self.input_fmt,
+                    &self.datatype,
+                );
                 self.convert_multiple_files(&files);
                 log::info!("{:18}: {}", "Output dir", self.output.display());
             }
             InputType::Wildcard => {
                 let files = self.parse_input_wcard(self.matches);
-                self.print_input_multi::<PathBuf>(&None, task_desc, files.len(), &self.input_fmt);
+                self.print_input_multi::<PathBuf>(
+                    &None,
+                    task_desc,
+                    files.len(),
+                    &self.input_fmt,
+                    &self.datatype,
+                );
                 self.convert_multiple_files(&files);
                 log::info!("{:18}: {}", "Output dir", self.output.display());
             }
@@ -70,7 +82,7 @@ impl<'a> ConvertParser<'a> {
 
     fn convert_file(&mut self, task_desc: &str) {
         let input = Path::new(self.parse_file_input(self.matches));
-        self.print_input_file(input, task_desc, &self.input_fmt);
+        self.print_input_file(input, task_desc, &self.input_fmt, &self.datatype);
         self.convert_any(input, &self.output, &self.output_fmt);
     }
 
